function dy= Wing_Func(t,y,td,Excitation_Total,Stiffness,damp)
%NEW_WING_FUNC is an ordinary differential equation associated with the 3D
%rotation of a flapping wing.  The solution is the time-dependent
%contribution of a generalized coordinate q.  Excitation_Total is the total
%time varying excitation generated by rotation.  Stiffness is the time
%varying stiffness matrix. t is the time scale being solved over.  td is
%the independent time used to evaluate the time varying paramters.  y is
%the response, and is equivalent to q.  

dy=zeros(2,1); %Initializing a system of first order ODE's
dy(1)=y(2);    %By definition, the derivative of y(1) equals y(2)

%Interpolating the time-varying parameters to sync with the differential
%equation.  The time-varying parameters are the stiffness and the
%excitation terms

Excitation_Total=interp1(td,Excitation_Total,t);
Stiffness=interp1(td,Stiffness,t);

%Setting up the first order differential equation for y(2)

dy(2)=Excitation_Total-Stiffness*y(1)-damp*y(2);


end

